pub struct TokioChildProcess { /* private fields */ }Implementations
Sourceimpl TokioChildProcess
impl TokioChildProcess
Sourcepub fn new(command: impl Into<CommandWrap>) -> Result<TokioChildProcess, Error>
pub fn new(command: impl Into<CommandWrap>) -> Result<TokioChildProcess, Error>
Convenience: spawn with default piped stdio
Sourcepub fn builder(command: impl Into<CommandWrap>) -> TokioChildProcessBuilder
pub fn builder(command: impl Into<CommandWrap>) -> TokioChildProcessBuilder
Builder entry-point allowing fine-grained stdio control.
Sourcepub async fn graceful_shutdown(&mut self) -> Result<(), Error>
pub async fn graceful_shutdown(&mut self) -> Result<(), Error>
Gracefully shutdown the child process
This will first close the transport to the child process (the server), and wait for the child process to exit normally with a timeout. If the child process doesn’t exit within the timeout, it will be killed.
Sourcepub fn into_inner(self) -> Option<Box<dyn ChildWrapper>>
pub fn into_inner(self) -> Option<Box<dyn ChildWrapper>>
Take ownership of the inner child process
Sourcepub fn split(self) -> (TokioChildProcessOut, ChildStdin)
👎Deprecated since 0.5.0: use the Transport trait implementation instead
pub fn split(self) -> (TokioChildProcessOut, ChildStdin)
use the Transport trait implementation instead
Split this helper into a reader (stdout) and writer (stdin).