pub struct StreamableHttpServerConfig {
pub sse_keep_alive: Option<Duration>,
pub sse_retry: Option<Duration>,
pub stateful_mode: bool,
pub json_response: bool,
pub cancellation_token: CancellationToken,
}Fields
sse_keep_alive: Option<Duration>The ping message duration for SSE connections.
sse_retry: Option<Duration>The retry interval for SSE priming events.
stateful_mode: boolIf true, the server will create a session for each request and keep it alive. When enabled, SSE priming events are sent to enable client reconnection.
json_response: boolWhen true and stateful_mode is false, the server returns
Content-Type: application/json directly instead of text/event-stream.
This eliminates SSE framing overhead for simple request-response tools,
allowed by the MCP Streamable HTTP spec (2025-06-18).
cancellation_token: CancellationTokenCancellation token for the Streamable HTTP server.
When this token is cancelled, all active sessions are terminated and the server stops accepting new requests.