pub struct StreamableHttpServerConfig {
pub sse_keep_alive: Option<Duration>,
pub stateful_mode: bool,
pub cancellation_token: CancellationToken,
}Fields
sse_keep_alive: Option<Duration>The ping message duration for SSE connections.
stateful_mode: boolIf true, the server will create a session for each request and keep it alive.
cancellation_token: CancellationTokenCancellation token for the Streamable HTTP server.
When this token is cancelled, all active sessions are terminated and the server stops accepting new requests.